@@ -15,7 +15,6 @@ import sys
 import datetime
 import radvelso
 
-
 def find_schema(schema):
   """find schema file contained in the Python package
 
@@ -31,7 +30,7 @@ def find_schema(schema):
   #root path of radvelso package (one dir up from radvelso module)
   package_dir = os.path.dirname(radvelso_dir)
   #full path of schema we are looking for
-  schema_file = f'{package_dir}/schema/{schema}'
+  schema_file = f'{package_dir}/radvelso/schema/{schema}'
 
   if not os.path.isfile(schema_file):
     raise ValueError(f'schema_file: {schema_file} does not exist')
@@ -146,38 +145,41 @@ def average_boxes(conn_filememory,
                   id_obs,
                   id_data,
                   azimuth,
-                  half_delta_range,
+                  half_delta_range_box,
                   range_bin_centers, 
-                  half_delta_azimuth):
+                  half_delta_azimuth_box,
+                  obs_percentage):
   """ Average input data found in range and azimuth "box"
      
   args:
-    conn_filememory      : connexcion to output file (and attached ppi_db)
-    id_obs               : id_obs for this ray
-    id_data              : id_data for this averaging box
-    azimuth              : center azimuth of averaging box
-    half_delta_range     : half of the delta_range for this averaging box
-    range_bin_centers    : range center for this averaging box 
-    half_delta_azimuth   : half of azimuthal span of averaging box
+    conn_filememory        : connexcion to output file (and attached ppi_db)
+    id_obs                 : id_obs for this ray
+    id_data                : id_data for this averaging box
+    azimuth                : center azimuth of averaging box
+    half_delta_range_box   : half of the delta_range for this averaging box
+    range_bin_centers      : range center for this averaging box 
+    half_delta_azimuth_box : half of azimuthal span of averaging box
 
   output:
     number of observations used in this average
   """
 
   # bounds of the box
-  right_azimuth   = azimuth+half_delta_azimuth
-  left_azimuth    = azimuth-half_delta_azimuth
-  range_box_start = range_bin_centers-half_delta_range
-  range_box_end   = range_bin_centers+half_delta_range
+  right_azimuth   = azimuth+half_delta_azimuth_box
+  left_azimuth    = azimuth-half_delta_azimuth_box
+  range_box_start = range_bin_centers-half_delta_range_box
+  range_box_end   = range_bin_centers+half_delta_range_box
 
   # Condition changes for azimuth centered at zero 
   condition="and"
   if (left_azimuth<0): 
-    left_azimuth=360.-half_delta_azimuth  
+    left_azimuth=360.-half_delta_azimuth_box  
     condition="or"
   
   order_sql = """ SELECT 
                     count(*),
+                    half_delta_azimuth,
+                    half_delta_range,
                     sum(center_elevation)
                   FROM
                     db_ppi.data natural join db_ppi.header 
@@ -197,19 +199,27 @@ def average_boxes(conn_filememory,
   cursor = conn_filememory.execute(order_sql, (range_box_start, range_box_end, left_azimuth, right_azimuth))
   result = cursor.fetchone()
   # get Num observation for thos box
-  number_obs_box=result[0]
+  number_obs_box = result[0]
+  half_delta_azimuth = result[1]
+  half_delta_range = result[2]
   # get sum elevation for this box
-  sum_elevation = result[1]
-
+  sum_elevation = result[3]
+  number_obs_percentage = 0.
   if number_obs_box == 0: 
 
     # no observations in averaging box, we exit here  
-    return 0, 0
+    return 0., 0., 0.
 
   else:
+    if (half_delta_azimuth==0):
+        half_delta_azimuth=0.5
+    if (half_delta_range==0):
+        half_delta_range = 125
+    number_obs_max = (half_delta_azimuth_box/half_delta_azimuth)*(half_delta_range_box/half_delta_range)
+    if ((100*number_obs_box/number_obs_max)>=obs_percentage):
 
-    # Write the found values of avg (obsvalue) (among others) in the box
-    order_sql = """INSERT into data(
+      # Write the found values of avg (obsvalue) (among others) in the box
+      order_sql = """INSERT into data(
                      id_obs, 
                      range, 
                      obsvalue, 
@@ -238,12 +248,12 @@ def average_boxes(conn_filememory,
                          center_azimuth >= ? """+condition+""" center_azimuth < ?
                      )"""
     
-    conn_filememory.execute(order_sql, (id_obs, range_bin_centers, 
-                                     half_delta_azimuth, half_delta_range, id_data, number_obs_box,
+      conn_filememory.execute(order_sql, (id_obs, range_bin_centers, 
+                                     half_delta_azimuth_box, half_delta_range_box, id_data, number_obs_box,
                                      range_box_start, range_box_end, left_azimuth, right_azimuth,))
+      number_obs_percentage = number_obs_box
 
-
-  return number_obs_box, sum_elevation
+  return number_obs_box, sum_elevation, number_obs_percentage
 
 
 def create_header(conn_filememory, 
@@ -422,6 +432,7 @@ def superobs(filein,
              pathfileout,
              ray_list, 
              ops_run_name, 
+             obs_percentage,
              timer=False):
 
   """ Average  a volume scan
@@ -438,6 +449,7 @@ def superobs(filein,
     ray_list      : averaging template containing info for how to average PPIs
     ops_run_name  : name of operational run 
     timer         : activation of time analysis, only the first PPI in a volume scan will be averaged
+    obs_percentage:
 
   output:
     This function outputs nothing
@@ -519,28 +531,33 @@ def superobs(filein,
 
       # average boxes and write result in data table of filememory db (Memory)
       sum_elev_ray   = 0.
-      number_obs_ray = 0
+      number_obs_ray = 0.
+      number_obs_ray_percentage = 0.
       for range_bin_center, half_delta_azimuth in zip(ray['range_bin_centers'], 
                                                       ray['half_delta_azimuth']):
              
-        number_obs_box, sum_elev_box = average_boxes(conn_filememory,
-                                                     id_obs,
-                                                     id_data,
-                                                     azimuth, 
-                                                     half_delta_range,
-                                                     range_bin_center,
-                                                     half_delta_azimuth)
+        number_obs_box, sum_elev_box, number_obs_percentage = average_boxes(conn_filememory,
+                                                                            id_obs,
+                                                                            id_data,
+                                                                            azimuth, 
+                                                                            half_delta_range,
+                                                                            range_bin_center,
+                                                                            half_delta_azimuth,
+                                                                            obs_percentage)
         if number_obs_box > 0:
-          id_data = (rng.integers(maxsize, size=1))[0].tolist()
+           number_obs_ray += number_obs_box
 
-          sum_elev_ray   += sum_elev_box
-          number_obs_ray += number_obs_box
+        if number_obs_percentage>0:
+            sum_elev_ray   += sum_elev_box
+            id_data = (rng.integers(maxsize, size=1))[0].tolist()
+            number_obs_percentage +=number_obs_percentage 
+            number_obs_ray_percentage += number_obs_percentage
       
       # if any data was found in ray, create header entry matching average bins
       # already entered in data table
-      if number_obs_ray > 0:
+      if number_obs_ray_percentage > 0:
 
-        avg_elevation = sum_elev_ray / number_obs_ray
+        avg_elevation = sum_elev_ray / number_obs_ray_percentage
 
         create_header(conn_filememory, 
                       ray, 
@@ -683,7 +700,8 @@ def compute_average(center_time,
          ops_run_name, 
          n_rays, 
          delta_range,
-         n_cpus):
+         n_cpus,
+         obs_percentage):
   """launch computation of average volums scans, possibly in parallel
 
   args:
@@ -698,7 +716,7 @@ def compute_average(center_time,
     n_rays       : number of rays
     delta_range  : delta range of the boxes
     n_cpus       : number of cpus for parallel execution, with n_cpus=1 joba are launched sequentially and dask is not invoked 
- 
+    obs_percentage : percentage of observation in the box to average
   output:
     Nothing
     Average sqlite file(s) are created with the '_thin' suffix
@@ -717,7 +735,7 @@ def compute_average(center_time,
 
   #init large output file
   conn_pathfileout = sqlite3.connect(pathfileout)
-
+  conn_pathfileout.execute("pragma temp_store = 2;")
   schema = find_schema('schema')
   with open(schema) as f:
     schema = f.read()
@@ -729,21 +747,20 @@ def compute_average(center_time,
     with sqlite3.connect(this_file) as conn_loops:
       # list of radars in the file
       avail_radar_list  = [ stn[0] for stn in conn_loops.execute("select distinct ID_STN from header order by 1;").fetchall() ]
-      print (avail_radar_list)
+   
+     
       for this_radar in avail_radar_list:
         #select radars if desired radar_list is specified
-        print (this_radar,desired_radar_list != 'all')
-        if desired_radar_list != 'all':
-          if this_radar not in avail_radar_list:
+        if desired_radar_list[0]  != 'all':
+          if this_radar not in desired_radar_list:
             continue
         # dates
         result = conn_loops.execute(f"select distinct DATE, printf('%06d', TIME) from header where ID_STN = '{this_radar}' ;").fetchall()
         datetime_list  = [datetime.datetime.strptime(f'{date_time[0]}{date_time[1]}', '%Y%m%d%H%M%S') for date_time in result]
         datetime_list.sort()
-        print ("DAVID",datetime_list)
+
         for this_date in datetime_list:
           #only include date in assimilation window
-          print (this_date ,'>', window_t0, this_date ,'<',window_tf)
           if (this_date > window_t0) and (this_date <= window_tf):
             vol_scan_list.append( {'file':this_file, 'radar':this_radar, 'date':this_date} )
   
@@ -752,7 +769,7 @@ def compute_average(center_time,
 
   print('make averaging template')
   #initialize template that will be used for averaging every PPIs
-  min_range_in_ppi =  10000.
+  min_range_in_ppi =  delta_range
   max_range_in_ppi = 240000.
   averaging_template = radvelso.fill_ray_dict(n_rays=n_rays,
                                               min_range_in_ppi = min_range_in_ppi,
@@ -767,7 +784,7 @@ def compute_average(center_time,
     this_radar = vol_scan_list[0]['radar']
     this_date  = vol_scan_list[0]['date']
     superobs(this_file, this_radar, this_date, 
-             pathfileout, averaging_template, ops_run_name, timer=True)
+             pathfileout, averaging_template, ops_run_name, obs_percentage, timer=True)
     tc_1 = time.time()
 
   else:
@@ -777,7 +794,7 @@ def compute_average(center_time,
       print('Serial execution')
       for vscan in vol_scan_list:
         superobs(vscan['file'] ,vscan['radar'], vscan['date'], 
-                 pathfileout, averaging_template, ops_run_name)
+                 pathfileout, averaging_template, ops_run_name, obs_percentage)
     else:
       print(f'Compute {len(vol_scan_list)} volume scans in parallel')
       with tempfile.TemporaryDirectory() as tmpdir:
@@ -790,7 +807,7 @@ def compute_average(center_time,
           #delay data 
           averaging_template = dask.delayed(averaging_template)
           joblist = [delayed(superobs)(vscan['file'], vscan['radar'], vscan['date'], 
-                                       pathfileout, averaging_template, ops_run_name) for vscan in vol_scan_list]
+                                       pathfileout, averaging_template, ops_run_name, obs_percentage) for vscan in vol_scan_list]
           dask.compute(joblist)
    
     sample_file  = vol_scan_list[0]['file']
@@ -821,25 +838,26 @@ def arg_call():
     parser.add_argument('--timing',       action="store_true",             help="Average only one PPI for time analysis" ) 
     parser.add_argument('--ops_run_name', default='N1',        type=str,   help="Name of operational run (will show up in rdb4_schema)" ) 
     parser.add_argument('--n_rays',       default=20,          type=int,   help="Number of rays for averaging" )
-    parser.add_argument('--delta_range',  default=10000.,      type=float, help="Delta_range  for averaging" )
+    parser.add_argument('--delta_range',  default=5000.,      type=float, help="Delta_range  for averaging" )
     parser.add_argument('--n_cpus',       default=1,           type=int,   help="Number of rays for averaging" )
+    parser.add_argument('--obs_percentage',default=50,          type=int,   help="Percentage of observation in the box to average" )
 
     args = parser.parse_args()
 
     if args.inputfiles == 'undefined' and args.pathin == 'undefined':
 
-      args.center_time = '2019073100'
+      args.center_time = '2019062706'
       args.window_width = 6.
-      args.desired_radar_list = ['casra', 'usdyx']
+      args.desired_radar_list = ['all']
       #option1: explicitely specify inputfiles
       #args.inputfiles = ['/space/hall4/sitestore/eccc/cmd/a/dlo001/data/doppler_qc/doppler_qc_v0.3/sqlite_v1.0.0_qc/split_6h/USVNX/2019073100_ra',
       #                   '/space/hall4/sitestore/eccc/cmd/a/dlo001/data/doppler_qc/doppler_qc_v0.3/sqlite_v1.0.0_qc/split_6h/CASRA/2019073100_ra']
       #option2: specify pathin + infile_struc and let Python search for files
-      args.pathin = '/space/hall4/sitestore/eccc/cmd/a/dlo001/data/doppler_qc/doppler_qc_v0.3/sqlite_v1.0.0_qc/split_6h/'
+      args.pathin = '/fs/site6/eccc/cmd/a/dlo001/data/doppler_qc/doppler_qc_v0.4/sqlite_v1.0.0_qc/split_6h/'
       args.pathout = './work'
       args.timing = False
       args.plot   = False
-      args.n_cpus = 40
+      args.n_cpus = 80
 
       print(f'superobs called with no input filename(s)')
       print(f'We are running demo with:')
@@ -884,7 +902,6 @@ def arg_call():
       os.mkdir(args.pathout)
 
     #sys.exit is used to the return status of main is catched and passed to caller
-    print (infile_list)
     sys.exit(compute_average(args.center_time,
                   args.window_width,
                   args.desired_radar_list,
@@ -895,7 +912,8 @@ def arg_call():
                   args.ops_run_name, 
                   args.n_rays, 
                   args.delta_range, 
-                  args.n_cpus) )
+                  args.n_cpus,
+                  args.obs_percentage))
 
 if __name__ == '__main__':
     arg_call()
